@@ -947,7 +947,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         self.keys_store = Gtk.ListStore(str)
         self.treeview_auth.set_model(self.keys_store)
         tr = Gtk.CellRendererText()
-        keys_col = Gtk.TreeViewColumn(_("Key"), tr, text=0)
+        keys_col = Gtk.TreeViewColumn(_("Key"), tr, markup=0)
         self.treeview_auth.append_column(keys_col)
         try:
             self.treeview_auth.enable_model_drag_dest(
@@ -1059,8 +1059,13 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
 
     def show_keys(self):
         self.keys_store.clear()
-        for key in self.apt_key.list():
-            self.keys_store.append([key])
+        for keyring in self.apt_key.list():
+            keyring = GLib.markup_escape_text(keyring)
+            filename, details = keyring.split("\n", 1)
+            if details:
+                self.keys_store.append([f"<b>{filename}</b>\n{details}"])
+            else:
+                self.keys_store.append([f"<b>{filename}</b>\nNo details"])
 
     def on_combobox_update_interval_changed(self, widget):
         """Set the update automation interval to the chosen one"""
@@ -1178,8 +1183,8 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
             return
         key = model.get_value(a_iter, 0)
         try:
-            if not self.backend.RemoveKey(key[:16]):
-                error(self.main,
+            if not self.backend.RemoveKey(key.split("\n", 1)[0].replace("<b>", "").replace("</b>", "")):
+                error(self.window_main,
                       _("Error removing the key"),
                       _("The key you selected could not be removed. "
                         "Please report this as a bug."))
