@@ -34,10 +34,10 @@ gi.require_version('PackageKitGlib', '1.0')
 from gi.repository import PackageKitGlib as packagekit
 from gi.repository import Gio
 
-from PyQt5 import uic
-from PyQt5.QtCore import *
-from PyQt5.QtGui import *
-from PyQt5.QtWidgets import *
+from PyQt6 import uic
+from PyQt6.QtCore import *
+from PyQt6.QtGui import *
+from PyQt6.QtWidgets import *
 
 import softwareproperties
 import softwareproperties.distro
@@ -45,8 +45,9 @@ from softwareproperties.SoftwareProperties import SoftwareProperties
 import softwareproperties.SoftwareProperties
 from .I18nHelper import *
 
-from aptsources.sourceslist import SourceEntry
+from aptsources.sourceslist import Deb822SourceEntry, SourceEntry
 from .DialogEdit import DialogEdit
+from .DialogEditDeb822 import DialogEditDeb822
 from .DialogAdd import DialogAdd
 from .DialogMirror import DialogMirror
 from .CdromProgress import CdromProgress
@@ -74,13 +75,21 @@ class SoftwarePropertiesQtUI(QWidget):
   def __init__(self, datadir):
       QWidget.__init__(self)
       uic.loadUi("%s/designer/main.ui" % datadir, self)
+      self.center_window()
+
+  def center_window(self):
+      screen_geometry = QApplication.primaryScreen().availableGeometry()
+      window_geometry = self.frameGeometry()
+      window_geometry.moveCenter(screen_geometry.center())
+      self.move(window_geometry.topLeft())
 
 class SoftwarePropertiesQt(SoftwareProperties):
   def __init__(self, datadir=None, options=None, parent=None, file=None, attachWinID=None):
     """ Provide a Qt-based graphical user interface to configure
         the used software repositories, corresponding authentication keys
         and update automation """
-    SoftwareProperties.__init__(self, options=options, datadir=datadir)
+    SoftwareProperties.__init__(self, options=options, datadir=datadir,
+                                deb822=True)
 
     self.options = options
     self.datadir = datadir
@@ -107,7 +116,7 @@ class SoftwarePropertiesQt(SoftwareProperties):
     # rejected() signal from Close button
     self.userinterface.buttonBox.rejected.connect(self.on_close_button)
 
-    self.userinterface.buttonBox.button(QDialogButtonBox.Reset).setEnabled(False)
+    self.userinterface.buttonBox.button(QDialogButtonBox.StandardButton.Reset).setEnabled(False)
 
     # Put some life into the user interface:
     self.init_server_chooser()
@@ -145,9 +154,9 @@ class SoftwarePropertiesQt(SoftwareProperties):
     self.userinterface.treeview_cdroms.itemChanged.connect(self.on_cdrom_source_toggled)
     self.userinterface.treeview2.itemClicked.connect(self.on_treeview_keys_cursor_changed)
 
-    self.button_close = self.userinterface.buttonBox.button(QDialogButtonBox.Close)
+    self.button_close = self.userinterface.buttonBox.button(QDialogButtonBox.StandardButton.Close)
     self.button_close.setIcon(QIcon.fromTheme("dialog-close"))
-    self.button_revert = self.userinterface.buttonBox.button(QDialogButtonBox.Reset)
+    self.button_revert = self.userinterface.buttonBox.button(QDialogButtonBox.StandardButton.Reset)
     self.button_revert.setIcon(QIcon.fromTheme("edit-undo"))
     self.button_revert.clicked.connect(self.on_button_revert_clicked)
 
@@ -366,9 +375,9 @@ class SoftwarePropertiesQt(SoftwareProperties):
             if inconsistent:
                 child.setCheckState(Qt.PartiallyChecked)
             elif active:
-                child.setCheckState(Qt.Checked)
+                child.setCheckState(Qt.CheckState.Checked)
             else:
-                child.setCheckState(Qt.Unchecked)
+                child.setCheckState(Qt.CheckState.Unchecked)
 
     # Enable or disable the component checkbuttons
     for child in self.userinterface.vbox_dist_comps_frame.children():
@@ -378,9 +387,9 @@ class SoftwarePropertiesQt(SoftwareProperties):
             if inconsistent:
                 child.setCheckState(Qt.PartiallyChecked)
             elif active:
-                child.setCheckState(Qt.Checked)
+                child.setCheckState(Qt.CheckState.Checked)
             else:
-                child.setCheckState(Qt.Unchecked)
+                child.setCheckState(Qt.CheckState.Unchecked)
 
     # If no components are enabled there will be no need for updates
     # and source code
@@ -394,11 +403,11 @@ class SoftwarePropertiesQt(SoftwareProperties):
     # Check for source code sources
     source_code_state = self.get_source_code_state()
     if source_code_state == True:
-        self.userinterface.checkbutton_source_code.setCheckState(Qt.Checked)
+        self.userinterface.checkbutton_source_code.setCheckState(Qt.CheckState.Checked)
     elif source_code_state == None:
         self.userinterface.checkbutton_source_code.setCheckState(Qt.PartiallyChecked)
     else:
-        self.userinterface.checkbutton_source_code.setCheckState(Qt.Unchecked)
+        self.userinterface.checkbutton_source_code.setCheckState(Qt.CheckState.Unchecked)
 
     # Will show a short explanation if no CDROMs are used
     if len(self.get_cdrom_sources()) == 0:
@@ -484,9 +493,9 @@ class SoftwarePropertiesQt(SoftwareProperties):
     """
     # FIXME: I find it rather questionable whether sender will work with pyqt doing weird signal handling
     tickBox = kapp.sender()
-    if tickBox.checkState() == Qt.Checked:
+    if tickBox.checkState() == Qt.CheckState.Checked:
         self.enable_component(str(tickBox.objectName()))
-    elif tickBox.checkState() == Qt.Unchecked:
+    elif tickBox.checkState() == Qt.CheckState.Unchecked:
         self.disable_component(str(tickBox.objectName()))
     self.set_modified_sourceslist()
 
@@ -500,18 +509,18 @@ class SoftwarePropertiesQt(SoftwareProperties):
     tickBox = kapp.sender()
     name = str(tickBox.objectName())
 
-    if tickBox.checkState() == Qt.Checked:
+    if tickBox.checkState() == Qt.CheckState.Checked:
         self.enable_child_source(name)
-    elif tickBox.checkState() == Qt.Unchecked:
+    elif tickBox.checkState() == Qt.CheckState.Unchecked:
         self.disable_child_source(name)
     # no way to set back to mixed state so turn off tristate
     tickBox.setTristate(False)
 
   def on_checkbutton_source_code_toggled(self):
     """ Disable or enable the source code for all sources """
-    if self.userinterface.checkbutton_source_code.checkState() == Qt.Checked:
+    if self.userinterface.checkbutton_source_code.checkState() == Qt.CheckState.Checked:
         self.enable_source_code_sources()
-    elif self.userinterface.checkbutton_source_code.checkState() == Qt.Unchecked:
+    elif self.userinterface.checkbutton_source_code.checkState() == Qt.CheckState.Unchecked:
         self.disable_source_code_sources()
     self.userinterface.checkbutton_source_code.setTristate(False)
 
@@ -586,13 +595,13 @@ class SoftwarePropertiesQt(SoftwareProperties):
     SoftwareProperties.revert(self)
     self.set_modified_sourceslist()
     self.show_auto_update_level()
-    self.userinterface.buttonBox.button(QDialogButtonBox.Reset).setEnabled(False)
+    self.userinterface.buttonBox.button(QDialogButtonBox.StandardButton.Reset).setEnabled(False)
     self.modified_sourceslist = False
 
   def set_modified_config(self):
     """The config was changed and now needs to be saved and reloaded"""
     SoftwareProperties.set_modified_config(self)
-    self.userinterface.buttonBox.button(QDialogButtonBox.Reset).setEnabled(True)
+    self.userinterface.buttonBox.button(QDialogButtonBox.StandardButton.Reset).setEnabled(True)
 
   def set_modified_sourceslist(self):
     """The sources list was changed and now needs to be saved and reloaded"""
@@ -600,7 +609,7 @@ class SoftwarePropertiesQt(SoftwareProperties):
     self.show_distro()
     self.show_isv_sources()
     self.show_cdrom_sources()
-    self.userinterface.buttonBox.button(QDialogButtonBox.Reset).setEnabled(True)
+    self.userinterface.buttonBox.button(QDialogButtonBox.StandardButton.Reset).setEnabled(True)
 
   def show_isv_sources(self):
     """ Show the repositories of independent software vendors in the
@@ -630,9 +639,9 @@ class SoftwarePropertiesQt(SoftwareProperties):
         contents = contents.replace("</b>", "")
         item = QTreeWidgetItem([contents])
         if not source.disabled:
-            item.setCheckState(0, Qt.Checked)
+            item.setCheckState(0, Qt.CheckState.Checked)
         else:
-            item.setCheckState(0, Qt.Unchecked)
+            item.setCheckState(0, Qt.CheckState.Unchecked)
         items.append(item)
     treeview.addTopLevelItems(items)
 
@@ -656,7 +665,7 @@ class SoftwarePropertiesQt(SoftwareProperties):
   def on_auto_update_toggled(self):
     """Enable or disable automatic updates and modify the user interface
        accordingly"""
-    if self.userinterface.checkbutton_auto_update.checkState() == Qt.Checked:
+    if self.userinterface.checkbutton_auto_update.checkState() == Qt.CheckState.Checked:
       self.userinterface.combobox_update_interval.setEnabled(True)
       self.userinterface.radiobutton_updates_inst_sec.setEnabled(True)
       self.userinterface.radiobutton_updates_download.setEnabled(True)
@@ -690,9 +699,14 @@ class SoftwarePropertiesQt(SoftwareProperties):
     item = self.userinterface.treeview_sources.currentItem()
     if item is not None:
         index = self.userinterface.treeview_sources.indexOfTopLevelItem(item)
-        dialogue = DialogEdit(self.userinterface, self.sourceslist, self.isv_sources[index], self.datadir)
+        if isinstance(self.isv_sources[index], Deb822SourceEntry):
+            dialogue = DialogEditDeb822(self.userinterface, self.sourceslist, self.isv_sources[index], self.datadir)
+        else:
+            dialogue = DialogEdit(self.userinterface, self.sourceslist, self.isv_sources[index], self.datadir)
         result = dialogue.run()
-        if result == QDialog.Accepted:
+        if result == QDialog.DialogCode.Accepted:
+            self.replace_source_entry(str(self.isv_sources[index]),
+                                      str(dialogue.new_source_entry))
             self.set_modified_sourceslist()
             self.show_isv_sources()
 
@@ -718,8 +732,10 @@ class SoftwarePropertiesQt(SoftwareProperties):
     home = QDir.homePath()
     if "SUDO_USER" in os.environ:
         home = os.path.expanduser("~%s" % os.environ["SUDO_USER"])
-    url = KUrl.fromPath(home)
-    filename = KFileDialog.getOpenFileName(url, 'application/pgp-keys', self.userinterface, _("Import key"))
+    filename = QFileDialog.getOpenFileName(self.userinterface,
+                                           _("Import key"),
+                                           home,
+                                           _("GPG key file (*.gpg)"))[0]
     if filename:
       if not self.add_key(filename):
         title = _("Error importing selected file")
@@ -735,7 +751,7 @@ class SoftwarePropertiesQt(SoftwareProperties):
     if item == None:
         return
     key = item.text(0)
-    if not self.remove_key(key[:16]):
+    if not self.remove_key(key.split("\n", 1)[0]):
       title = _("Error removing the key")
       text = _("The key you selected could not be removed. "
                "Please report this as a bug.")
@@ -767,14 +783,14 @@ class SoftwarePropertiesQt(SoftwareProperties):
        only if there is no parent defined"""
     if self.modified_sourceslist == True and self.options.no_update == False:
         messageBox = QMessageBox(self.userinterface)
-        messageBox.setIcon(QMessageBox.Information)
-        reloadButton = messageBox.addButton(_("Reload"), QMessageBox.AcceptRole)
-        messageBox.addButton(QMessageBox.Close)
+        messageBox.setIcon(QMessageBox.Icon.Information)
+        reloadButton = messageBox.addButton(_("Reload"), QMessageBox.ButtonRole.AcceptRole)
+        messageBox.addButton(QMessageBox.StandardButton.Close)
         primary = _("Your local copy of the software catalog is out of date.")
         secondary = _("A new copy will be downloaded.")
         text = "%s<br /><br /><small>%s</small>" % (primary, secondary)
         messageBox.setText(text)
-        messageBox.exec_()
+        messageBox.exec()
         if (messageBox.clickedButton() == reloadButton):
                 self._pdialog = QProgressDialog("<big>{}</big>".format(_("Refreshing software cache")),
                                                 "Cancel", 0, 100, self.userinterface)
@@ -843,7 +859,7 @@ class SoftwarePropertiesQt(SoftwareProperties):
       self.set_modified_sourceslist()
 
   def run(self):
-    kapp.exec_()
+    kapp.exec()
 
   def on_driver_changes_progress(self, progress, ptype, data=None):
     self.button_driver_revert.setVisible(False)
@@ -1010,7 +1026,7 @@ class SoftwarePropertiesQt(SoftwareProperties):
     self.userinterface.box_driver_action.addWidget(self.button_driver_cancel)
 
     self.label_driver_detail = QLabel("Searching for available drivers...")
-    self.label_driver_detail.setAlignment(Qt.AlignCenter)
+    self.label_driver_detail.setAlignment(Qt.AlignmentFlag.AlignCenter)
     self.userinterface.box_driver_detail.addWidget(self.label_driver_detail)
 
     self.progress_bar = QProgressBar()
